From 90f907abcd3d196ef1abae754335fac36b57d68b Mon Sep 17 00:00:00 2001
From: U-ACER-1424F82190\raiska <raiska@acer-1424f82190.(none)>
Date: Sun, 2 Nov 2008 00:22:33 +0200
Subject: [PATCH] Fix QT4 trancoding for ipod and PSP (porfiles)

---
 modules/gui/qt4/dialogs/sout.cpp |   30 ++++++++++++++++++++++++++++--
 1 files changed, 28 insertions(+), 2 deletions(-)

diff --git a/modules/gui/qt4/dialogs/sout.cpp b/modules/gui/qt4/dialogs/sout.cpp
index 6ea0f62..f54b840 100644
--- a/modules/gui/qt4/dialogs/sout.cpp
+++ b/modules/gui/qt4/dialogs/sout.cpp
@@ -74,6 +74,7 @@ struct sout_gui_descr_t
 
     /* Transcode */
     bool b_soverlay; /*< enable burning overlay in the video */
+    bool b_usescale; /*< do we use scale or resolution options*/
     char *psz_vcodec;   /*< video codec to use in transcoding */
     char *psz_acodec;   /*< audio codec to use in transcoding */
     char *psz_scodec;   /*< subtitle codec to use in transcoding */
@@ -81,6 +82,8 @@ struct sout_gui_descr_t
     int32_t i_ab;       /*< audio bitrate to use in transcoding */
     int32_t i_channels; /*< number of audio channels to use in transcoding */
     float f_scale;      /*< scaling factor to use in transcoding */
+    int32_t i_reswidth; /*< width of video resolution */
+    int32_t i_resheight; /*< height of video resolution */
 
     /* Misc */
     bool b_sap;   /*< send SAP announcement */
@@ -365,7 +368,7 @@ void SoutDialog::setOptions()
     else if( profileString == "h264" ) setProfile( TS, true, "h264", true, "mp4a" )
     else if( profileString == "XBox" ) setProfile( ASF, true, "WMV2", true, "wma" )
     else if( profileString == "Windows" ) setProfile( ASF, true, "WMV2", true, "wma" )
-    else if( profileString == "PSP" ) setProfile( Ogg, true, "DIV3", true, "vorb" )
+    else if( profileString == "PSP" ) setProfile( MP4, true, "mp4v", true, "mp4a" )
 
         /* If the profile is not a custom one, then disable the tabWidget */
         if ( profileString == "Custom" )
@@ -475,6 +478,7 @@ void SoutDialog::updateMRL()
     sout.b_sap = ui.sap->isChecked();
     sout.b_all_es = ui.soutAll->isChecked();
     sout.b_sout_keep = ui.soutKeep->isChecked();
+    sout.b_usescale = true; /* We default to scale option */
     sout.psz_vcodec = strdup( qtu( ui.vCodecBox->itemData( ui.vCodecBox->currentIndex() ).toString() ) );
     sout.psz_acodec = strdup( qtu( ui.aCodecBox->itemData( ui.aCodecBox->currentIndex() ).toString() ) );
     sout.psz_scodec = strdup( qtu( ui.subsCodecBox->itemData( ui.subsCodecBox->currentIndex() ).toString() ) );
@@ -499,6 +503,23 @@ void SoutDialog::updateMRL()
     sout.f_scale = atof( qta( ui.vScaleBox->currentText() ) );
     sout.psz_group = strdup( qtu( ui.sapGroup->text() ) );
     sout.psz_name = strdup( qtu( ui.sapName->text() ) );
+    /* TODO: Add resolution selection to GUI */
+    sout.i_reswidth = 0;
+    sout.i_resheight = 0;
+    /* Override scale with resolution with certain profiles */
+    /* TODO: move below to SoutDialog::setOptions() */
+#define setResolution(width, height) \
+    { \
+	        sout.i_reswidth = width; \
+	        sout.i_resheight = height; \
+	        sout.b_usescale = false; \
+    }
+
+    QString profileString =
+    	ui.profileBox->itemData( ui.profileBox->currentIndex() ).toString();
+    if( profileString == "IPod" ) setResolution(320, 240)
+    else if( profileString == "PSP" ) setResolution(320, 240)
+    else sout.b_usescale = true;
 
     if ( sout.b_local ) counter++ ;
     if ( sout.b_file ) counter++ ;
@@ -535,7 +556,12 @@ void SoutDialog::updateMRL()
         {
             smrl.option( "vcodec", sout.psz_vcodec );
             smrl.option( "vb", sout.i_vb );
-            smrl.option( "scale", sout.f_scale );
+            if( sout.b_usescale ) smrl.option( "scale", sout.f_scale );
+            else
+            {
+            	smrl.option( "width", sout.i_reswidth );
+            	smrl.option( "canvas-height", sout.i_resheight );
+            }
             trans = true;
         }
 
-- 
1.6.0.2

